Packaging
=========

Virtue allows SKILL++ code to be organized into modules.  Then SKILL++ 
packages can be defined which contain multiple SKILL++ modules.

This packaging system allows many modules to be defined without naming 
collisions.  It also allows new tools to be easily added to the SKILL 
environment.

.. toctree::
   :caption: Contents:
   :hidden:

   modules
   skill_packages
